@@ -1,15 +1,14 @@
-from elementmaster import ElementMaster
 from PyQt5.QtCore import Qt, QCoreApplication, pyqtSignal, QVariant
 from PyQt5.QtGui import  QPixmap, QPainter, QColor
 from PyQt5.QtWidgets import QVBoxLayout, QLabel, QTextEdit, QWidget, QComboBox, QCheckBox
-import logging
+import logging, os.path
 from time import sleep
 from datetime import datetime
 from multiprocessing import Process
-from record_function import Record, Function
-from dropbox import DropBox
-from elements.basic_sched import ExecSched
-import os.path
+from Pythonic.record_function import Record, Function
+from Pythonic.dropbox import DropBox
+from Pythonic.elements.basic_sched import ExecSched
+from Pythonic.elementmaster import ElementMaster
 
 class StartElement(ExecSched):
 
@@ -91,8 +90,8 @@ class ExecRFunction(Function):
 class PlaceHolder(ElementMaster):
 
     # function is connected to add_func() of Workingarea
-    func_drop = pyqtSignal(int, int, str, name='func_block_drop')
-    query_config = pyqtSignal(int, int, name='query_config')
+    func_drop = pyqtSignal(int, int, str, str, name='func_block_drop')
+    #query_config = pyqtSignal(int, int, name='query_config')
     pixmap_path = 'images/placeholder.png'
     child_pos = (False, False)
 
@@ -121,19 +120,22 @@ class PlaceHolder(ElementMaster):
     def dropEvent(self, e):
 
         if e.mimeData().hasText():
-            logging.debug('mime data: {}'.format(e.mimeData().text()))
-            logging.debug('event: {}'.format(e.source()))
-            self.func_drop.emit(self.row, self.column, e.mimeData().text())
-            if isinstance(e.source(), DropBox):
-                logging.debug('dropEvent() query config')
+            logging.debug('PlaceHolder::dropEvent() mime data: {}'.format(e.mimeData().text()))
+            logging.debug('PlaceHolder::dropEvent() event: {}'.format(e.source()))
+            self.func_drop.emit(self.row, self.column, e.mimeData().text(), type(e.source()).__name__)
+            # DropBox is of type <class 'sip.wrappertype'>
+            """
+            if (type(e.source()).__name__ == DropBox.__name__):
+                logging.debug('PlaceHolder::dropEvent() query config')
                 self.query_config.emit(self.row, self.column)
+            """
 
     def dragEnterEvent(self, e):
 
-        logging.debug('dragEnterEvent() at pos: {}'.format(e.pos()))
+        logging.debug('PlaceHolder::dragEnterEvent() at pos: {}'.format(e.pos()))
         if e.mimeData().hasText():
-            logging.debug('mime data: {}'.format(e.mimeData().text()))
-            logging.debug('event: {}'.format(e))
+            logging.debug('PlaceHolder::dragLeaveEvent() mime data: {}'.format(e.mimeData().text()))
+            logging.debug('PlaceHolder::dragEnterEvent() event: {}'.format(e))
             newImg = 'images/' +  e.mimeData().text() + '.png'
             if os.path.isfile(newImg):
                 self.alterPixmap(QPixmap(newImg))
