@@ -1,17 +1,14 @@
-from elementmaster import ElementMaster
 from PyQt5.QtCore import Qt, QCoreApplication, pyqtSignal, QVariant
 from PyQt5.QtGui import  QPixmap, QPainter, QColor, QIntValidator, QDoubleValidator
 from PyQt5.QtWidgets import QVBoxLayout, QHBoxLayout, QLineEdit, QPushButton, QLabel, QTextEdit, QWidget, QComboBox, QCheckBox, QStackedWidget
 from elementeditor import ElementEditor
 from PyQt5.QtCore import QCoreApplication as QC
-import logging
-from time import sleep
-import os.path, datetime
-from record_function import Record, Function
-from elementmaster import alphabet
-from binance.client import Client
+from pythonic_binance.client import Client
 import pandas as pd
-
+import os.path, datetime, logging
+from time import sleep
+from Pythonic.record_function import Record, Function
+from Pythonic.elementmaster import ElementMaster
 
 class BinanceOrder(ElementMaster):
 
@@ -482,6 +479,7 @@ class BinanceOrder(ElementMaster):
             else:
 
                 stop_price_value = float(self.take_profit_limit_stop_price_input.text())
+        # TODO: Create Test Order
 
 
             logging.warning('Limit price: {}'.format(limit_price_value))
@@ -505,7 +503,8 @@ class BinanceOrder(ElementMaster):
         order_string    = self.selectOrder.currentData()
         log_state       = self.log_checkbox.isChecked()
 
-        self.config = (pub_key, prv_key, side_index, side_txt, symbol_txt, quantity, order_index, order_string, order_config, log_state)
+        self.config = (pub_key, prv_key, side_index, side_txt, symbol_txt,
+                quantity, order_index, order_string, order_config, log_state)
 
         self.addFunction(BinanceOrderFunction)
 
@@ -520,7 +519,8 @@ class BinanceOrderFunction(Function):
     def execute(self, record):
 
         
-        pub_key, prv_key, side_index, side_txt, symbol_txt, quantity, order_index, order_string, order_config, log_state = self.config
+        pub_key, prv_key, side_index, side_txt, symbol_txt, quantity, \
+                order_index, order_string, order_config, log_state = self.config
 
         timeInForce = None
         stopPrice   = None
@@ -658,6 +658,7 @@ class BinanceOrderFunction(Function):
         logging.error('stopPrice = {}'.format(stopPrice))
 
         log_txt = '{BINANCE ORDER}          '
-        result = Record(self.getPos(), (self.row +1, self.column), order, log=log_state, log_txt=log_txt)
+        result = Record(self.getPos(), (self.row +1, self.column), order,
+                 log=log_state, log_txt=log_txt)
 
         return result
