@@ -1,28 +1,22 @@
-from PyQt5.QtWidgets import (QWidget, QApplication,
-                            QFrame, QPushButton, QTextEdit,
-                            QHBoxLayout, QAction, QMainWindow,
-                            QVBoxLayout, QSizePolicy, QMenu, QMessageBox,
-                            QGridLayout, QSizeGrip, QTabWidget, QMenuBar,
-                            QLabel, QScrollArea, QGraphicsView, QGraphicsScene)
-from PyQt5.QtCore import (Qt, QMimeData, QByteArray, QDataStream, QPoint, QLocale,
-                         QThreadPool, QDir, pyqtSignal, pyqtSlot, QRect, QTranslator, QEvent)
-from PyQt5.QtGui import (QDrag, QPixmap, QPainter,QColor,
-                        QScreen, QPainter, QFont)
-
+from PyQt5.QtWidgets import (QWidget, QApplication, QFrame, QHBoxLayout,
+                            QVBoxLayout, QSizePolicy, QMessageBox,
+                            QSizeGrip, QTabWidget, QLabel, QScrollArea)
+from PyQt5.QtCore import (Qt, QMimeData, QLocale, QThreadPool, QDir,
+                              pyqtSignal, QRect, QTranslator, QEvent)
+from PyQt5.QtGui import (QDrag, QPixmap, QPainter, QScreen, QFont)
 from PyQt5.QtCore import QCoreApplication as QC
-import sys, logging, datetime, os
-#from defaultelements import StartElement, ExecRB, ExecR, ExecOp, ExecBranch, PlaceHolder
-import multiprocessing as mp
-from workingarea import WorkingArea
-from menubar import MenuBar
-from executor import GridOperator
-from top_menubar import topMenuBar
-from binancetools import BinanceTools
-from mastertool import MasterTool
-from elementmaster import alphabet
-from settings import Settings
-from info import InfoWindow
 from pathlib import Path
+import sys, logging, datetime, os
+import multiprocessing as mp
+from Pythonic.workingarea import WorkingArea
+from Pythonic.menubar import MenuBar
+from Pythonic.executor import GridOperator
+from Pythonic.top_menubar import topMenuBar
+from Pythonic.binancetools import BinanceTools
+from Pythonic.mastertool import MasterTool
+from Pythonic.elementmaster import alphabet
+from Pythonic.settings import Settings
+from Pythonic.info import InfoWindow
 
 
 class BasicTools(QFrame):
@@ -304,7 +298,7 @@ class MainWindow(QWidget):
     def changeEvent(self, event):
         if event.type() == QEvent.LanguageChange:
             logging.debug('changeEvent() called MainWindow')
-            self.setWindowTitle(QC.translate('', 'Pythonic - 0.7'))
+            self.setWindowTitle(QC.translate('', 'Pythonic - 0.8'))
 
     def showInfo(self, event):
 
