@@ -1,32 +1,23 @@
+from PyQt5.QtWidgets import QFrame, QGridLayout, QMessageBox
+from PyQt5.QtCore import Qt, pyqtSignal
+
+from Pythonic.elements.basicelements     import StartElement, ExecRB, ExecR, PlaceHolder
+from Pythonic.elements.basic_operation   import ExecOp
+from Pythonic.elements.basic_branch      import ExecBranch
+from Pythonic.elements.basic_return      import ExecReturn
+from Pythonic.elements.basic_process     import ExecProcess
+from Pythonic.elements.basic_ta          import ExecTA
+from Pythonic.elements.basic_sched       import ExecSched
+from Pythonic.elements.basic_stack       import ExecStack
+from Pythonic.elements.binance_sched     import BinanceSched
+from Pythonic.elements.binance_ohlc      import BinanceOHLC
+from Pythonic.elements.binance_order     import BinanceOrder
+
+from Pythonic.elementmaster              import ElementMaster
+from Pythonic.storagebar                 import StorageBar
+from Pythonic.dropbox                    import DropBox
+
 import logging, pickle
-from PyQt5.QtWidgets import (QWidget,
-                            QApplication,
-                            QFrame,
-                            QHBoxLayout,
-                            QVBoxLayout,
-                            QGridLayout,
-                            QLabel,
-                            QMessageBox)
-from PyQt5.QtCore import (Qt, QMimeData, QByteArray, QDataStream, QPoint,
-                                     QDir, pyqtSignal, pyqtSlot)
-from PyQt5.QtGui import (QDrag, QPixmap, QPainter,QColor,
-                        QScreen)
-
-from elements.basicelements     import StartElement, ExecRB, ExecR, PlaceHolder
-from elements.basic_operation   import ExecOp
-from elements.basic_branch      import ExecBranch
-from elements.basic_return      import ExecReturn
-from elements.basic_process     import ExecProcess
-from elements.basic_ta          import ExecTA
-from elements.basic_sched       import ExecSched
-from elements.basic_stack       import ExecStack
-from elements.binance_sched     import BinanceSched
-from elements.binance_ohlc      import BinanceOHLC
-from elements.binance_order     import BinanceOrder
-
-from elementmaster              import ElementMaster
-from storagebar                 import StorageBar
-
 
 class WorkingArea(QFrame):
 
@@ -41,7 +32,7 @@ class WorkingArea(QFrame):
         self.setAcceptDrops(True)
         self.setObjectName('workBackground')
         self.setStyleSheet('#workBackground { background-color: \
-                qlineargradient(x1:0 y1:0, x2:1 y2:1, stop:0 silver, stop:1 #ff5900)}')
+        qlineargradient(x1:0 y1:0, x2:1 y2:1, stop:0 #366a97, stop: 0.5 silver, stop:1 #ffc634)}')
 
         # mastergrid enshures the right positioning of the function blocks
         # mastergrid is static and the grid inside can grow
@@ -77,7 +68,10 @@ class WorkingArea(QFrame):
         self.registered_types.append(tool_tuple)
 
 
-    def addElement(self, row, column, newType):
+    def addElement(self, row, column, newType, source):
+
+        logging.debug('WorkingArea::addElement() source: {}'.format(source)) 
+        # source argument for elements with a config
 
         # deletes the placeholder where the new object was dropped
 
@@ -90,6 +84,8 @@ class WorkingArea(QFrame):
             logging.error('addElement()- desired element type not found')
             logging.error(e)
             return
+
+        
         # setup parent position
 
         # setting the parent element
@@ -104,6 +100,26 @@ class WorkingArea(QFrame):
 
         self.grid.addWidget(new_type, row, column, Qt.AlignCenter)
 
+        # load config when source was dropbox
+        # ABKÜRZUNG MÖGLICH BAUSTELLE (LoadCOnfig muss nicht aufgerufen werden oder
+        # nur mit element als argument
+        if source == DropBox.__name__ :
+            #self.loadConfig(row, column)
+            logging.debug('WorkingArea::addElement() config: {}'.format(new_type)) 
+            #element = new_type
+            #element = self.grid.itemAtPosition(row, column).widget()
+            new_type.config = self.storage_bar.returnConfig()
+            # element was not pickled! 
+            # call __getstate__ and __addstate_ to update the function
+            # by calling addFunction of the elementmastern 
+
+            # the when the config has changed (or loaded from the dropbox) the function 
+            # of the element has to be reassigned with the new configuration
+
+            func_type = type(new_type.function)
+            logging.debug('WorkingArea::loadConfig() function type: {}'.format(func_type))
+            new_type.addFunction(func_type)
+
         # add second placeholder in case of a added branch function
         # connect delete button to related grid method
         new_type.del_sig.connect(self.delete_element)
@@ -181,11 +197,12 @@ class WorkingArea(QFrame):
             if element:
                 if (isinstance(element.widget(), ExecRB) and 
                     isinstance(element.widget().parent_element, ExecR)):
-                    logging.debug('element found at: ', (row, col))
+                    logging.debug('WorkingArea::reduceGrid() element found at: {} {}'.format(row, col))
                     #if self.checkLeft(row, col):
                     if self.stepLeft(row, col):
                         # repeat if a childTree was moved
-                        logging.debug('Looking again for child trees that can be moved ')
+                        logging.debug('WorkingArea::reduceGrid() Looking again for child trees \
+                                that can be moved ')
                         # find missing links for the purpose that this function can find 
                         #child trees again
                         self.findMissingLinks()
@@ -196,7 +213,7 @@ class WorkingArea(QFrame):
 
     def checkDeletion(self, target):
 
-        logging.debug('checkDeletion() called')
+        logging.debug('WorkingArea::checkDeletion() called')
         
         bot_child = self.grid.itemAtPosition(target.row + 1, target.column)
         if not bot_child:
@@ -251,12 +268,13 @@ class WorkingArea(QFrame):
             self.moveColParent(parent)
             self.findMissingLinks()
             self.addPlaceholder(row, column +1)
+            # update position of placeholder for query config ?
+
         
         else:
             # actual position is valid
             target = PlaceHolder(row, column)
             target.func_drop.connect(self.addElement)
-            target.query_config.connect(self.loadConfig)
     
             # set child element
             parent = self.grid.itemAtPosition(row-1, column).widget()
@@ -355,7 +373,7 @@ class WorkingArea(QFrame):
         self.moveColParent(candidate)
 
     def moveColParent(self, candidate):
-        #print('checkColParent()')
+
         parent_row, parent_col = candidate.parent_element.getPos()
         #parent_element = self.grid.itemAtPosition(parent_row, parent_col).widget()
         if parent_col == candidate.column:
@@ -379,9 +397,10 @@ class WorkingArea(QFrame):
         row, column = candidate.getPos()
         self.checkRight(row, column)
 
-        logging.debug('moveElement() moveElement called at row: {} column:  {}'.format(row, column))
-        logging.debug('moveElement() candidate type: {}'.format(type(candidate)))
-        logging.debug('moveElement() add candidate to position: {}'.format(row, column+1))
+        logging.debug('WorkingArea::moveElement() moveElement called at row: {} column:  {}'.format(
+            row, column))
+        logging.debug('WorkingArea::moveElement() candidate type: {}'.format(type(candidate)))
+        logging.debug('WorkingArea::moveElement() add candidate to position: {}'.format(row, column+1))
         # setze child elemente neu
         #element = self.grid.itemAtPosition(row, column)
         #element = element.widget()
@@ -393,23 +412,22 @@ class WorkingArea(QFrame):
 
         grid_cols = range(1, self.grid.columnCount())
         grid_rows = range(1, self.grid.rowCount())
-        logging.debug('number of rows: {} number of columns: {}'.format( 
+        logging.debug('WorkingArea::findMissingLinks() number of rows: {} number of columns: {}'.format( 
             self.grid.rowCount(), self.grid.columnCount()))
 
         index = ((row, column) for row in grid_rows for column in grid_cols)
 
-        logging.debug('findMissingLinks() called')
         for pos in index:
             row, col = pos
-            logging.debug('check position: {}'.format(row, col))
+            logging.debug('WorkingArea::findMissingLinks() check position: {}'.format(row, col))
             element = self.grid.itemAtPosition(row, col)
             if element and isinstance(element.widget(), ExecRB):
-                logging.debug('element is RB: {} '.format(row, col))
+                logging.debug('WorkingArea::findMissingLinks() element is RB: {} '.format(row, col))
                 element_col = element.widget().column
                 parent_col  = element.widget().parent_element.column
 
                 if element_col - parent_col > 1:
-                    logging.debug('missing link at: {}'.format(pos))
+                    logging.debug('WorkingArea::findMissingLinks() missing link at: {}'.format(pos))
                     link = ExecR(row, col-1)
                     link.setChild(element.widget())
                     
@@ -425,7 +443,7 @@ class WorkingArea(QFrame):
 
     def saveGrid(self, filename):
 
-        logging.debug('saveGrid() called with fileName {}'.format(filename))
+        logging.debug('WorkingArea::saveGrid() called with fileName {}'.format(filename))
         grid_cols = range(0, self.grid.columnCount())
         grid_rows = range(0, self.grid.rowCount())
 
@@ -435,10 +453,10 @@ class WorkingArea(QFrame):
 
         for pos in index:
             row, col = pos
-            logging.debug('saveGrid() check position: {} {}'.format(row, col))
+            logging.debug('WorkingArea::saveGrid() check position: {} {}'.format(row, col))
             element = self.grid.itemAtPosition(row, col)
-            if element and isinstance(element.widget(), ElementMaster):
-                logging.debug('saveGrid() element found at: {} {}'.format(row, col))
+            if element:
+                logging.debug('WorkingArea::saveGrid() element found at: {} {}'.format(row, col))
                 element_list.append(element.widget())
 
         with open(filename, 'wb') as save_file:
@@ -492,12 +510,22 @@ class WorkingArea(QFrame):
 
         # populate the grid
         for element in element_list:
+            
             row, col = element.getPos()
+            logging.debug('WorkingArea::loadGrid() ADD current element: row: {} col: {}'.format(
+                row, col))
+            logging.debug('WorkingArea::loadGrid() ADD element:{}'.format(
+                element))
+            logging.debug('WorkingArea::loadGrid() ADD element type:{}'.format(
+                type(element)))
+
             self.grid.addWidget(element, row, col)
 
         # second run: add child and parent relation
         for element in element_list:
             row, col = element.getPos()
+            logging.debug('WorkingArea::loadGrid() current element: row: {} col: {}'.format(
+                row, col))
 
             if element.child_pos[0]:
 
@@ -509,16 +537,30 @@ class WorkingArea(QFrame):
                 child = self.grid.itemAtPosition(row, col+1).widget()
                 element.setChild(child)
             
-            if isinstance(element, ExecR) or isinstance(element, ExecRB):
+
+            if (type(element).__name__ == ExecR.__name__ or
+                type(element).__name__ == ExecRB.__name__):
+                parent = self.grid.itemAtPosition(row, col-1)
+                logging.debug('WorkingArea::loadGrid() parent:{}'.format(
+                    parent))
+
+                logging.debug('WorkingArea::loadGrid() type parent:{}'.format(
+                    type(parent)))
+
+
                 parent = self.grid.itemAtPosition(row, col-1).widget()
                 element.parent_element = parent
-            elif not isinstance(element, StartElement):
+            #elif not isinstance(element, StartElement):
+
+            elif (type(element).__name__ != StartElement.__name__):
                 parent = self.grid.itemAtPosition(row-1, col).widget()
                 element.parent_element = parent
 
-            if isinstance(element, PlaceHolder):
+            #if isinstance(element, PlaceHolder):
+
+            if (type(element).__name__ == PlaceHolder.__name__):    
                 element.func_drop.connect(self.addElement)
-                element.query_config.connect(self.loadConfig)
+                #element.query_config.connect(self.loadConfig)
             else:
                 element.del_sig.connect(self.delete_element)
 
@@ -553,20 +595,3 @@ class WorkingArea(QFrame):
             element = self.grid.itemAtPosition(*element_pos).widget()
             element.highlightStop()
 
-    def loadConfig(self, row, column):
-
-        logging.debug('loadConfig() called')
-        # when this function is called, storabar will delete the placeholder
-
-        element = self.grid.itemAtPosition(row, column).widget()
-        element.config = self.storage_bar.returnConfig()
-        # element was not pickled! 
-        # call __getstate__ and __addstate_ to update the function
-        # by calling addFunction of the elementmastern 
-
-        # the when the config has changed (or loaded from the dropbox) the function 
-        # of the element has to be reassigned with the new configuration
-
-        func_type = type(element.function)
-        element.addFunction(func_type)
-
